@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 1998 Free Software Foundation, Inc.                        *
+ * Copyright (c) 1998,2000 Free Software Foundation, Inc.                   *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -27,12 +27,13 @@
  ****************************************************************************/
 
 /****************************************************************************
- *   Author: Juergen Pfeifer <juergen.pfeifer@gmx.net> 1995,1997            *
+ *   Author:  Juergen Pfeifer, 1995,1997                                    *
+ *   Contact: http://www.familiepfeifer.de/Contact.aspx?Lang=en             *
  ****************************************************************************/
 
 #include "form.priv.h"
 
-MODULE_ID("$Id: fld_info.c,v 1.4 1999/05/16 17:17:52 juergen Exp $")
+MODULE_ID("$Id: fld_info.c,v 1.6 2002/07/06 15:33:27 juergen Exp $")
 
 /*---------------------------------------------------------------------------
 |   Facility      :  libnform  
@@ -46,10 +47,12 @@ MODULE_ID("$Id: fld_info.c,v 1.4 1999/05/16 17:17:52 juergen Exp $")
 |   Return Values :  E_OK           - success
 |                    E_BAD_ARGUMENT - invalid field pointer
 +--------------------------------------------------------------------------*/
-int field_info(const FIELD *field,
-	       int *rows, int *cols, 
-	       int *frow, int *fcol, 
-	       int *nrow, int *nbuf)
+NCURSES_EXPORT(int)
+field_info 
+    (const FIELD *field,
+     int *rows, int *cols, 
+     int *frow, int *fcol, 
+     int *nrow, int *nbuf)
 {
   if (!field) 
     RETURN(E_BAD_ARGUMENT);
@@ -75,8 +78,9 @@ int field_info(const FIELD *field,
 |   Return Values :  E_OK           - success
 |                    E_BAD_ARGUMENT - invalid argument
 +--------------------------------------------------------------------------*/
-int dynamic_field_info(const FIELD *field,
-		       int *drows, int *dcols, int *maxgrow)
+NCURSES_EXPORT(int)
+dynamic_field_info
+(const FIELD *field, int *drows, int *dcols, int *maxgrow)
 {
   if (!field)
     RETURN(E_BAD_ARGUMENT);
