@@ -27,7 +27,8 @@
  ****************************************************************************/
 
 /****************************************************************************
- *   Author: Juergen Pfeifer <juergen.pfeifer@gmx.net> 1995,1997            *
+ *   Author:  Juergen Pfeifer, 1995,1997                                    *
+ *   Contact: http://www.familiepfeifer.de/Contact.aspx?Lang=en             *
  ****************************************************************************/
 
 /***************************************************************************
@@ -37,7 +38,9 @@
 
 #include "menu.priv.h"
 
-MODULE_ID("$Id: m_global.c,v 1.12 2000/12/10 02:16:48 tom Exp $")
+MODULE_ID("$Id: m_global.c,v 1.14 2002/07/06 15:22:16 juergen Exp $")
+
+static char mark[] = "-";
 
 NCURSES_EXPORT_VAR(MENU) _nc_Default_Menu = {
   16,				  /* Nr. of chars high */
@@ -73,7 +76,7 @@ NCURSES_EXPORT_VAR(MENU) _nc_Default_Menu = {
   (Menu_Hook)0,			  /* Item init */
   (Menu_Hook)0,			  /* Item term */
   (void *)0,			  /* userptr */
-  "-",				  /* mark */
+  mark,				  /* mark */
   ALL_MENU_OPTS,                  /* options */
   0			          /* status */	    
 };
