@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 1998,1999,2000,2001 Free Software Foundation, Inc.         *
+ * Copyright (c) 1998-2001,2002 Free Software Foundation, Inc.              *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -36,7 +36,7 @@
 #include <curses.priv.h>
 #include <ctype.h>
 
-MODULE_ID("$Id: lib_addch.c,v 1.63 2001/12/19 01:05:42 tom Exp $")
+MODULE_ID("$Id: lib_addch.c,v 1.68 2002/09/28 17:48:13 tom Exp $")
 
 /*
  * Ugly microtweaking alert.  Everything from here to end of module is
@@ -63,7 +63,7 @@ render_char(WINDOW *win, NCURSES_CH_T ch)
 	SetAttr(ch, a | (AttrOf(win->_nc_bkgd) & COLOR_MASK(a)));
     } else {
 	/* color in attrs has precedence over bkgrnd */
-	a |= (AttrOf(win->_nc_bkgd) & A_ATTRIBUTES) & COLOR_MASK(a);
+	a |= AttrOf(win->_nc_bkgd) & COLOR_MASK(a);
 	/* color in ch has precedence */
 	AddAttr(ch, (a & COLOR_MASK(AttrOf(ch))));
     }
@@ -128,14 +128,39 @@ waddch_literal(WINDOW *win, NCURSES_CH_T ch)
 
     CHANGED_CELL(line, x);
 
+    /*
+     * Handle non-spacing characters
+     */
+    if_WIDEC({
+	if (wcwidth(CharOf(ch)) == 0) {
+	    int i;
+	    int y;
+	    if ((x > 0 && ((y = win->_cury) >= 0))
+		|| ((y = win->_cury - 1) >= 0 &&
+		    (x = win->_maxx) > 0)) {
+		wchar_t *chars = (win->_line[y].text[x - 1].chars);
+		for (i = 0; i < CCHARW_MAX; ++i) {
+		    if (chars[i] == 0) {
+			chars[i] = CharOf(ch);
+			break;
+		    }
+		}
+	    }
+	    goto testwrapping;
+	}
+    });
     line->text[x++] = ch;
-    if_WIDEC( {
-	     if (wcwidth(CharOf(ch)) > 1)
-	     AddAttr(line->text[x++], WA_NAC);
-	     }
-    )
+    /*
+     * Provide for multi-column characters
+     */
+    if_WIDEC({
+	if (wcwidth(CharOf(ch)) > 1)
+	    AddAttr(line->text[x++], WA_NAC);
+    }
+  testwrapping:
+    );
 
-	TR(TRACE_VIRTPUT, ("(%d, %d) = %s", win->_cury, x, _tracech_t(CHREF(ch))));
+    TR(TRACE_VIRTPUT, ("(%d, %d) = %s", win->_cury, x, _tracech_t(CHREF(ch))));
     if (x > win->_maxx) {
 	/*
 	 * The _WRAPPED flag is useful only for telling an application that
