@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 1998,1999,2000 Free Software Foundation, Inc.              *
+ * Copyright (c) 1998-2001,2002 Free Software Foundation, Inc.              *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -39,31 +39,7 @@
 extern int malloc_errfd;	/* FIXME */
 #endif
 
-MODULE_ID("$Id: lib_freeall.c,v 1.19 2001/09/15 21:32:48 tom Exp $")
-
-static void
-free_slk(SLK * p)
-{
-    if (p != 0) {
-	FreeIfNeeded(p->ent);
-	FreeIfNeeded(p->buffer);
-	free(p);
-    }
-}
-
-static void
-free_tries(struct tries *p)
-{
-    struct tries *q;
-
-    while (p != 0) {
-	q = p->sibling;
-	if (p->child != 0)
-	    free_tries(p->child);
-	free(p);
-	p = q;
-    }
-}
+MODULE_ID("$Id: lib_freeall.c,v 1.20 2002/07/28 00:35:25 tom Exp $")
 
 /*
  * Free all ncurses data.  This is used for testing only (there's no practical
@@ -73,6 +49,7 @@ NCURSES_EXPORT(void)
 _nc_freeall(void)
 {
     WINDOWLIST *p, *q;
+    char *s;
 
 #if NO_LEAKS
     _nc_free_tparm();
@@ -98,24 +75,16 @@ _nc_freeall(void)
 		}
 	    }
 	}
-
-	free_tries(SP->_keytry);
-	free_tries(SP->_key_ok);
-	free_slk(SP->_slk);
-	FreeIfNeeded(SP->_color_pairs);
-	FreeIfNeeded(SP->_color_table);
-	FreeIfNeeded(SP->oldhash);
-	FreeIfNeeded(SP->newhash);
-	FreeIfNeeded(SP->hashtab);
-#if !BROKEN_LINKER
-	FreeAndNull(SP);
-#endif
+	delscreen(SP);
     }
 
     if (cur_term != 0) {
 	_nc_free_termtype(&(cur_term->type));
 	free(cur_term);
     }
+
+    if ((s = _nc_home_terminfo()) != 0)
+	free(s);
 #ifdef TRACE
     (void) _nc_trace_buf(-1, 0);
 #endif
