@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 1998,2000,2001 Free Software Foundation, Inc.              *
+ * Copyright (c) 1998-2001,2002 Free Software Foundation, Inc.              *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -36,18 +36,18 @@
  */
 #include <curses.priv.h>
 
-MODULE_ID("$Id: lib_tracechr.c,v 1.7 2001/12/30 00:14:35 tom Exp $")
+MODULE_ID("$Id: lib_tracechr.c,v 1.9 2002/05/25 23:34:19 tom Exp $")
 
 #ifdef TRACE
 NCURSES_EXPORT(char *)
 _tracechar(int ch)
 {
     static char crep[40];
-    (void) sprintf(crep, "'%.30s' = 0x%02x",
-		   (ch > KEY_MIN)
-		   ? keyname(ch)
-		   : unctrl(ch),
-		   (unsigned) ch);
+    (void) sprintf(crep, "'%.30s' = %#03o",
+		   ((ch > KEY_MIN || ch < 0)
+		    ? keyname(ch)
+		    : unctrl(ch)),
+		   ch);
     return (crep);
 }
 #else
