@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 1998,1999,2000,2001,2002 Free Software Foundation, Inc.    *
+ * Copyright (c) 1998-2001,2002 Free Software Foundation, Inc.              *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -41,12 +41,14 @@
  *
  *-----------------------------------------------------------------*/
 
+#include <curses.priv.h>
+
 #ifdef __BEOS__
+#undef false
+#undef true
 #include <OS.h>
 #endif
 
-#include <curses.priv.h>
-
 #if defined(TRACE) && HAVE_SYS_TIMES_H && HAVE_TIMES
 #define USE_TRACE_TIMES 1
 #else
@@ -70,7 +72,7 @@
 
 #include <term.h>
 
-MODULE_ID("$Id: tty_update.c,v 1.173 2002/01/12 22:22:27 tom Exp $")
+MODULE_ID("$Id: tty_update.c,v 1.177 2002/09/28 20:41:55 tom Exp $")
 
 /*
  * This define controls the line-breakout optimization.  Every once in a
@@ -208,7 +210,7 @@ PutAttrChar(CARG_CH_T ch)
      * make it work for wide characters.
      */
     if (SP->_outch != 0) {
-	SP->_outch(ch);
+	SP->_outch((int) ch);
     } else
 #endif
     {
@@ -483,11 +485,10 @@ EmitRange(const NCURSES_CH_T * ntext, int num)
  * Returns: same as EmitRange
  */
 static int
-PutRange(
-	    const NCURSES_CH_T * otext,
-	    const NCURSES_CH_T * ntext,
-	    int row,
-	    int first, int last)
+PutRange(const NCURSES_CH_T * otext,
+	 const NCURSES_CH_T * ntext,
+	 int row,
+	 int first, int last)
 {
     int j, run;
 
@@ -1471,7 +1472,7 @@ _nc_outstr(const char *str)
 static int
 scroll_csr_forward(int n, int top, int bot, int miny, int maxy, NCURSES_CH_T blank)
 {
-    int i, j;
+    int i;
 
     if (n == 1 && scroll_forward && top == miny && bot == maxy) {
 	GoTo(bot, 0);
@@ -1512,6 +1513,7 @@ scroll_csr_forward(int n, int top, int bot, int miny, int maxy, NCURSES_CH_T bla
 
 #if NCURSES_EXT_FUNCS
     if (FILL_BCE()) {
+	int j;
 	for (i = 0; i < n; i++) {
 	    GoTo(bot - i, 0);
 	    for (j = 0; j < screen_columns; j++)
@@ -1528,7 +1530,7 @@ static int
 scroll_csr_backward(int n, int top, int bot, int miny, int maxy,
 		    NCURSES_CH_T blank)
 {
-    int i, j;
+    int i;
 
     if (n == 1 && scroll_reverse && top == miny && bot == maxy) {
 	GoTo(top, 0);
@@ -1569,6 +1571,7 @@ scroll_csr_backward(int n, int top, int bot, int miny, int maxy,
 
 #if NCURSES_EXT_FUNCS
     if (FILL_BCE()) {
+	int j;
 	for (i = 0; i < n; i++) {
 	    GoTo(top + i, 0);
 	    for (j = 0; j < screen_columns; j++)
@@ -1623,8 +1626,7 @@ scroll_idl(int n, int del, int ins, NCURSES_CH_T blank)
 }
 
 NCURSES_EXPORT(int)
-_nc_scrolln
-(int n, int top, int bot, int maxy)
+_nc_scrolln(int n, int top, int bot, int maxy)
 /* scroll region from top to bot by n lines */
 {
     NCURSES_CH_T blank = ClrBlank(stdscr);
@@ -1754,8 +1756,24 @@ _nc_screen_resume(void)
     SP->_current_attr = A_NORMAL;
     newscr->_clear = TRUE;
 
-    if (SP->_coloron == TRUE && orig_pair)
-	putp(orig_pair);
+    /* reset color pairs and definitions */
+    if (SP->_coloron || SP->_color_defs)
+	_nc_reset_colors();
+
+    /* restore user-defined colors, if any */
+    if (SP->_color_defs < 0) {
+	int n;
+	SP->_color_defs = -(SP->_color_defs);
+	for (n = 0; n < SP->_color_defs; ++n) {
+	    if (SP->_color_table[n].init) {
+		init_color(n,
+			   SP->_color_table[n].r,
+			   SP->_color_table[n].g,
+			   SP->_color_table[n].b);
+	    }
+	}
+    }
+
     if (exit_attribute_mode)
 	putp(exit_attribute_mode);
     else {
@@ -1799,6 +1817,9 @@ _nc_screen_wrap(void)
 	ClrToEOL(blank, TRUE);
     }
 #endif
+    if (SP->_color_defs) {
+	_nc_reset_colors();
+    }
 }
 
 #if USE_XMC_SUPPORT
