@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 1998,1999,2000,2001 Free Software Foundation, Inc.         *
+ * Copyright (c) 1998-2001,2002 Free Software Foundation, Inc.              *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -29,6 +29,7 @@
 /****************************************************************************
  *  Author: Zeyd M. Ben-Halim <zmbenhal@netcom.com> 1992,1995               *
  *     and: Eric S. Raymond <esr@snark.thyrsus.com>                         *
+ *     and: Thomas E. Dickey 1996 on                                        *
  ****************************************************************************/
 
 /*
@@ -44,7 +45,7 @@
 #include <term_entry.h>
 #include <transform.h>
 
-MODULE_ID("$Id: tic.c,v 1.92 2001/06/18 18:44:01 tom Exp $")
+MODULE_ID("$Id: tic.c,v 1.102 2002/10/05 19:59:41 tom Exp $")
 
 const char *_nc_progname = "tic";
 
@@ -88,24 +89,27 @@ usage(void)
     {
 	"Options:",
 	"  -1         format translation output one capability per line",
-	"  -C         translate entries to termcap source form",
-	"  -I         translate entries to terminfo source form",
-	"  -L         translate entries to full terminfo source form",
-	"  -N         disable smart defaults for source translation",
-	"  -R         restrict translation to given terminfo/termcap version",
-	"  -T         remove size-restrictions on compiled description",
-	"  -V         print version",
 #if NCURSES_XNAMES
 	"  -a         retain commented-out capabilities (sets -x also)",
 #endif
+	"  -C         translate entries to termcap source form",
 	"  -c         check only, validate input without compiling or translating",
+	"  -e<names>  translate/compile only entries named by comma-separated list",
 	"  -f         format complex strings for readability",
 	"  -G         format %{number} to %'char'",
 	"  -g         format %'char' to %{number}",
-	"  -e<names>  translate/compile only entries named by comma-separated list",
+	"  -I         translate entries to terminfo source form",
+	"  -L         translate entries to full terminfo source form",
+	"  -N         disable smart defaults for source translation",
 	"  -o<dir>    set output directory for compiled entry writes",
+	"  -R<name>   restrict translation to given terminfo/termcap version",
 	"  -r         force resolution of all use entries in source translation",
 	"  -s         print summary statistics",
+	"  -T         remove size-restrictions on compiled description",
+#if NCURSES_XNAMES
+	"  -t         suppress commented-out capabilities",
+#endif
+	"  -V         print version",
 	"  -v[n]      set verbosity level",
 	"  -w[n]      set format width for translation output",
 #if NCURSES_XNAMES
@@ -442,6 +446,7 @@ main(int argc, char *argv[])
     const char **namelst = 0;
     char *outdir = (char *) NULL;
     bool check_only = FALSE;
+    bool suppress_untranslatable = FALSE;
 
     log_fp = stderr;
 
@@ -465,7 +470,7 @@ main(int argc, char *argv[])
      * be optional.
      */
     while ((this_opt = getopt(argc, argv,
-			      "0123456789CILNR:TVace:fGgo:rsvwx")) != EOF) {
+			      "0123456789CILNR:TVace:fGgo:rstvwx")) != EOF) {
 	if (isdigit(this_opt)) {
 	    switch (last_opt) {
 	    case 'v':
@@ -541,6 +546,10 @@ main(int argc, char *argv[])
 	    width = 0;
 	    break;
 #if NCURSES_XNAMES
+	case 't':
+	    _nc_disable_period = FALSE;
+	    suppress_untranslatable = TRUE;
+	    break;
 	case 'a':
 	    _nc_disable_period = TRUE;
 	    /* FALLTHRU */
@@ -659,7 +668,7 @@ main(int argc, char *argv[])
     if (check_only && (capdump || infodump)) {
 	for_entry_list(qp) {
 	    if (matches(namelst, qp->tterm.term_names)) {
-		int len = fmt_entry(&qp->tterm, NULL, TRUE, infodump, numbers);
+		int len = fmt_entry(&qp->tterm, NULL, FALSE, TRUE, infodump, numbers);
 
 		if (len > (infodump ? MAX_TERMINFO_LENGTH : MAX_TERMCAP_LENGTH))
 		    (void) fprintf(stderr,
@@ -698,7 +707,8 @@ main(int argc, char *argv[])
 			    put_translate(fgetc(tmp_fp));
 		    }
 
-		    len = dump_entry(&qp->tterm, limited, numbers, NULL);
+		    len = dump_entry(&qp->tterm, suppress_untranslatable,
+				     limited, 0, numbers, NULL);
 		    for (j = 0; j < qp->nuses; j++)
 			len += dump_uses(qp->uses[j].name, !capdump);
 		    (void) putchar('\n');
@@ -822,8 +832,8 @@ expected_params(const char *name)
 	{ "sgr1",		6 },
 	{ "slength",		1 },
 	{ "slines",		1 },
-	{ "smgbp",		2 },
-	{ "smglp",		2 },
+	{ "smgbp",		1 },	/* 2 if smgtp is not given */
+	{ "smglp",		1 },
 	{ "smglr",		2 },
 	{ "smgrp",		1 },
 	{ "smgtb",		2 },
@@ -863,6 +873,12 @@ check_params(TERMTYPE * tp, const char *name, char *value)
     bool params[10];
     char *s = value;
 
+#ifdef set_top_margin_parm
+    if (!strcmp(name, "smgbp")
+	&& set_top_margin_parm == 0)
+	expected = 2;
+#endif
+
     for (n = 0; n < 10; n++)
 	params[n] = FALSE;
 
@@ -901,6 +917,14 @@ check_params(TERMTYPE * tp, const char *name, char *value)
     }
 }
 
+static char *
+skip_delay(char *s)
+{
+    while (*s == '/' || isdigit(UChar(*s)))
+	++s;
+    return s;
+}
+
 /*
  * An sgr string may contain several settings other than the one we're
  * interested in, essentially sgr0 + rmacs + whatever.  As long as the
@@ -908,8 +932,25 @@ check_params(TERMTYPE * tp, const char *name, char *value)
  * sanity check.
  */
 static bool
-similar_sgr(char *a, char *b)
+similar_sgr(int num, char *a, char *b)
 {
+    static const char *names[] =
+    {
+	"none"
+	,"standout"
+	,"underline"
+	,"reverse"
+	,"blink"
+	,"dim"
+	,"bold"
+	,"invis"
+	,"protect"
+	,"altcharset"
+    };
+    char *base_a = a;
+    char *base_b = b;
+    int delaying = 0;
+
     while (*b != 0) {
 	while (*a != *b) {
 	    if (*a == 0) {
@@ -917,11 +958,31 @@ similar_sgr(char *a, char *b)
 		    && b[1] == '<') {
 		    _nc_warning("Did not find delay %s", _nc_visbuf(b));
 		} else {
-		    _nc_warning("Unmatched portion %s", _nc_visbuf(b));
+		    _nc_warning("checking sgr(%s) %s\n\tcompare to %s\n\tunmatched %s",
+				names[num], _nc_visbuf2(1, base_a),
+				_nc_visbuf2(2, base_b),
+				_nc_visbuf2(3, b));
 		}
 		return FALSE;
+	    } else if (delaying) {
+		a = skip_delay(a);
+		b = skip_delay(b);
+	    } else {
+		a++;
 	    }
-	    a++;
+	}
+	switch (*a) {
+	case '$':
+	    if (delaying == 0)
+		delaying = 1;
+	    break;
+	case '<':
+	    if (delaying == 1)
+		delaying = 2;
+	    break;
+	default:
+	    delaying = 0;
+	    break;
 	}
 	a++;
 	b++;
@@ -945,9 +1006,11 @@ check_sgr(TERMTYPE * tp, char *zero, int num, char *cap, const char *name)
     tparm_errs += _nc_tparm_err;
     if (test != 0) {
 	if (PRESENT(cap)) {
-	    if (!similar_sgr(test, cap)) {
-		_nc_warning("%s differs from sgr(%d): %s", name, num,
-			    _nc_visbuf(test));
+	    if (!similar_sgr(num, test, cap)) {
+		_nc_warning("%s differs from sgr(%d)\n\t%s=%s\n\tsgr(%d)=%s",
+			    name, num,
+			    name, _nc_visbuf2(1, cap),
+			    num, _nc_visbuf2(2, test));
 	    }
 	} else if (strcmp(test, zero)) {
 	    _nc_warning("sgr(%d) present, but not %s", num, name);
@@ -1018,8 +1081,9 @@ check_termtype(TERMTYPE * tp)
      * non-ANSI strings are misused.
      */
     if ((max_colors > 0) != (max_pairs > 0)
-	|| (max_colors > max_pairs))
-	_nc_warning("inconsistent values for max_colors and max_pairs");
+	|| ((max_colors > max_pairs) && (initialize_pair == 0)))
+	_nc_warning("inconsistent values for max_colors (%d) and max_pairs (%d)",
+		    max_colors, max_pairs);
 
     PAIRED(set_foreground, set_background);
     PAIRED(set_a_foreground, set_a_background);
@@ -1064,13 +1128,13 @@ check_termtype(TERMTYPE * tp)
 
     /*
      * Some standard applications (e.g., vi) and some non-curses
-     * applications (e.g., jove) get confused if we have both ich/ich1 and
+     * applications (e.g., jove) get confused if we have both ich1 and
      * smir/rmir.  Let's be nice and warn about that, too, even though
      * ncurses handles it.
      */
     if ((PRESENT(enter_insert_mode) || PRESENT(exit_insert_mode))
-	&& (PRESENT(insert_character) || PRESENT(parm_ich))) {
-	_nc_warning("non-curses applications may be confused by ich/ich1 with smir/rmir");
+	&& PRESENT(parm_ich)) {
+	_nc_warning("non-curses applications may be confused by ich1 with smir/rmir");
     }
 
     /*
