@@ -3,7 +3,7 @@
  *
  * Generate timing statistics for vertical-motion optimization.
  *
- * $Id: hashtest.c,v 1.19 2001/09/15 21:42:27 tom Exp $
+ * $Id: hashtest.c,v 1.22 2002/06/29 23:32:18 tom Exp $
  */
 
 #ifdef TRACE
@@ -14,9 +14,7 @@
 #define USE_TRACE 0
 #endif
 
-#include <string.h>
 #include <ctype.h>
-#include <signal.h>
 
 #include <test.priv.h>
 
@@ -165,6 +163,8 @@ main(int argc, char *argv[])
     int test_normal = FALSE;
     int test_optimize = FALSE;
 
+    setlocale(LC_ALL, "");
+
     while ((c = getopt(argc, argv, "cf:h:l:norsx")) != EOF) {
 	switch (c) {
 	case 'c':
