@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (c) 2000,2001 Free Software Foundation, Inc.                   *
+ * Copyright (c) 2000-2001,2002 Free Software Foundation, Inc.              *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
  * copy of this software and associated documentation files (the            *
@@ -29,16 +29,14 @@
 /*
  * Author: Thomas E. Dickey <dickey@clark.net> 2000
  *
- * $Id: railroad.c,v 1.8 2001/09/15 22:16:24 tom Exp $
+ * $Id: railroad.c,v 1.10 2002/04/06 20:45:22 tom Exp $
  *
  * A simple demo of the termcap interface.
  */
-#include <termcap.h>
-#include <ctype.h>
-#include <signal.h>
-
 #include <test.priv.h>
 
+#include <ctype.h>
+
 static char *wipeit;
 static char *moveit;
 static int length;
