@@ -92,10 +92,8 @@
 /******************************************************************************/
 
 /*
- * $Id: xmas.c,v 1.17 2001/09/15 22:02:05 tom Exp $
+ * $Id: xmas.c,v 1.19 2002/06/29 23:32:18 tom Exp $
  */
-#include <signal.h>
-
 #include <test.priv.h>
 
 #define FROMWHO "Mark Hessling - (M.Hessling@gu.edu.au)"
@@ -190,6 +188,8 @@ main(int argc GCC_UNUSED, char **argv GCC_UNUSED)
 {
     int loopy;
 
+    setlocale(LC_ALL, "");
+
     initscr();
     noecho();
     nonl();
